//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------
#include <stdio.h>
#include <stdlib.h>
#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules
#include "menu.h"

void welcomeScreen(void);	//Declaration of the function that prints Welcome String on Hyperterminal

extern char timer_flag = 0;		//flag for the 100ms timer interrupt
extern char timer_counter = 0;	//counter for keeping track of 100ms increments
extern char led_flag = 0;		//flag for the MCU board LED to toggle


// Main Function //
void main(void)
{
	extern BYTE Port_0_Data_SHADE;	
	Port_0_Data_SHADE = 0;
	
	M8C_EnableIntMask(INT_MSK0, INT_MSK0_GPIO);
	M8C_EnableGInt; // Uncomment this line to enable Global Interrupts
	
	Timer16_LED_EnableInt();
	Timer16_LED_Start();
	
    UART_CmdReset(); 							//Initialize receiver/cmd buffer
    UART_IntCntl(UART_ENABLE_RX_INT);   		//Enable RX interrupts    
    UART_Start(UART_PARITY_NONE);   			//set parity as zero and start the UART
	
	welcomeScreen();
	printMenu();
	
	while (1){
		
		/* Increment timer_counter and reset flag. Set timer derived flags*/
		if (timer_flag){
			timer_flag = 0;
			timer_counter++;
			
			/* Generate event flags based off the timer_counter*/
			if (timer_counter%10 == 0){			//Set flags every second for LED and nixie update
				led_flag = 1;
			}
		}
		
		/* Reset timer_counter when it reaches 200 in order to keep moduluses working correctly in base 10*/
		if (timer_counter > 199)
			timer_counter = 0;
		
		/* Check event flags in order of priority and execute appropriate code of the first one raised*/
		if (led_flag){
			led_flag = 0;
			Port_0_Data_SHADE ^= 0X40;
			PRT0DR = Port_0_Data_SHADE;			//Toggle LED (Port 0, Pin 6)
		}
		
		menu_process();
	}
}



//------------------------------------------------------------------------ 
// welcomeScreen() Function to print the welcome screen
//------------------------------------------------------------------------
void welcomeScreen(void)
{
    UART_CPutString("\n\rWelcome to the PSoC Nixie terminal.\n\r");
}





#pragma interrupt_handler GPIO_ISR

/* GPIO ISR in C to detect button presses*/
void GPIO_ISR(void)
{	

}


#pragma interrupt_handler Timer_ISR

/* Timer ISR in C where timer interrupts are processed */
void Timer_ISR(void)
{
	timer_flag = 1;
}
